@@ -146,6 +146,9 @@ class Device:
     def clear_write_log(self):
         self.write_log = bytes()
 
+    def set_bit_mode(self, mask: int, enable: bool):
+        raise SerialDeviceNotImplementedException(f'set_bit_mode not available on {self.__class__.__name__} devices')
+
 
 class MockDevice(Device):
     def __init__(self, input_buffer: Optional[bytes]=None):
@@ -225,6 +228,9 @@ class FtdiDevice(Device):
     def read(self, num_bytes: int, raw: bool = True) -> bytes:
         return self.ftdi.read(num_bytes, raw)
 
+    def set_bit_mode(self, mask: int, enable: bool):
+        self.ftdi.setBitMode(mask, enable)
+
 
 class PySerialDevice(Device):
     PARITIES = {
@@ -681,3 +687,11 @@ class Serial:
         """
         self.device.purge(self.FT_PURGE_TX)
 
+    def set_bit_mode(self, mask: int, enable: bool):
+        """
+        Enable or disable bit-bang mode on FTDI devices
+        :param mask: bit mask for I/O direction (1 is output)
+        :param enable: enables bit-bang mode if True, disables if False
+        :return:
+        """
+        self.device.set_bit_mode(mask, enable)
\ No newline at end of file
